package com.example.youtube_videos;

import java.util.List;

import com.example.youtube_videos.model.Video;

import android.content.Context;
import android.view.LayoutInflater;
import android.view.View;
import android.view.ViewGroup;
import android.widget.BaseAdapter;
import android.widget.TextView;

/** A slightly more complicated adapter
 * 
 * @author tomas
 *
 */
public class VideoAdapter extends BaseAdapter {

	private List<Video> list;
	private Context context;
	
	public VideoAdapter(Context context, List<Video> list) {
		super();
		this.list = list;
		this.context = context;
	}

	public int getCount() {
		return list != null ? list.size() : 0;
	}

	public Object getItem(int position) {
		return list.get(position);
	}

	public long getItemId(int position) {
		return position;
	}

	public View getView(int position, View convertView, ViewGroup parent) {
		View view = convertView;
		if(view == null) {
			LayoutInflater inflater = LayoutInflater.from(context);
			view = inflater.inflate(R.layout.item_videos_list, null);
			ViewHolder holder = new ViewHolder();
			holder.tvTitle = (TextView) view.findViewById(R.id.tv_title);
			holder.tvDuration = (TextView) view.findViewById(R.id.tv_duration);
			view.setTag(holder); // attach view holder to the view
		} // else recycle the convertView (it was previously used and I can use it freely for new item) 
		
		Video item = (Video) getItem(position);
		
		ViewHolder holder = (ViewHolder) view.getTag(); // get the view holder
		holder.tvTitle.setText(item.getTitle());
//		holder.tvDuration.setText( String.valueOf(item.getDuration()) ); // QUESTION - If we would use this line instead of the next one, why do we need the conversion to String?
		holder.tvDuration.setText( convertDuration(item.getDuration()) );
		return view;
	}
	
	private String convertDuration(int duration) {
		int hours = duration / 3600;
		int minutes = (duration % 3600) / 60;
		int seconds = duration % 60;
		return String.format("%1$01d:%2$02d:%3$02d", hours, minutes, seconds);
	}

	// view holder pattern to prevent unnecessary calling to findViewById
	// makes the list much faster
	static class ViewHolder {
		public TextView tvTitle;
		public TextView tvDuration;
	}
}
