package com.example.youtube_videos.fragment;

import com.example.youtube_videos.GetUserDetailAsyncTask;
import com.example.youtube_videos.IDataAccessor;

import android.app.Activity;
import android.os.Bundle;
import android.support.v4.app.Fragment;

// worker fragment that survives activity destruction and recreation
public class RetainedWorkerFragment extends Fragment {

	private static final String EXTRA_USER = "extra-user";
	private static final String EXTRA_DATA_ACCESSOR = "extra-data-accessor";
	
	private GetUserDetailAsyncTask asyncTask;
	private String user;

	private RetainedWorkerFragment() {
		super();
	}
        
	public static RetainedWorkerFragment newInstance(IDataAccessor dataAccessor, String user) {
		RetainedWorkerFragment fragment = new RetainedWorkerFragment();
		Bundle args = new Bundle();
		args.putString(EXTRA_USER, user);
		args.putSerializable(EXTRA_DATA_ACCESSOR, dataAccessor);
		fragment.setArguments(args);
		return fragment;
	}
	
    /**
     * Fragment initialization.  We way we want to be retained and
     * start our thread.
     */
    @Override
    public void onCreate(Bundle savedInstanceState) {
        super.onCreate(savedInstanceState);
        
        // Tell the framework to try to keep this fragment around
        // during a configuration change.
            setRetainInstance(true);
            
           	this.user = getArguments().getString(EXTRA_USER);
           	IDataAccessor dataAccessor = (IDataAccessor) getArguments().getSerializable(EXTRA_DATA_ACCESSOR);
           	asyncTask = new GetUserDetailAsyncTask(dataAccessor);
           	asyncTask.execute(this.user);
        }

 

        /**
     * This is called when the fragment is going away.  It is NOT called
     * when the fragment is being propagated between activity instances.
     */
    @Override
    public void onDestroy() {
        if(asyncTask != null && !asyncTask.isCancelled())
        	asyncTask.cancel(true);
        
        super.onDestroy();
    }

    /**
     * This is called right before the fragment is detached from its
     * current activity instance.
     */
    @Override
    public void onDetach() {
        // This fragment is being detached from its activity.  We need
        // to make sure its thread is not going to touch any activity
        // state after returning from this function.
    	
        super.onDetach();
    }
    
	@Override
	public void onAttach(Activity activity) {
		// called when attached to an activity
		// reattaching the async task
		if(asyncTask != null && activity instanceof IDataAccessor)
			asyncTask.attach( (IDataAccessor) activity );
		super.onAttach(activity);
	}

}
